@@ -2,8 +2,7 @@ package Local::Bar;
 
 use Log4Perl::ImportHandle 'logging';
 
-use Moose;
-
+sub new {};
 
 
 sub test {
